@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 61 $
+# Revision: $Rev: 154 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -315,7 +315,7 @@ class AMCFile33(AbstractFile):
         """
         self.__file.write(AMCFile33.__fileVersionID)        
         for data in ['name', 'mail', 'icq', 'site', 'description']:           
-            raw = self[data]
+            raw = self[data] or ""
             try:
                 value = unicode(raw).encode('utf8')
             except UnicodeDecodeError, e:
